@@ -27,9 +27,9 @@ class Job(metaclass=ABCMeta):
             individual.state = individual.State.IN_PROGRESS
 
             # check the constraints
-            constraints = self.problem.evaluate_constraints(individual)
+            constraints = self.problem.evaluate_inequality_constraints(individual.vector)
 
-            if constraints:
+            if len(constraints) > 0:
                 individual.features["feasible"] = sum(map(abs, constraints))
 
             # problem cost function evaluate only in that case when the problem fits the constraints
@@ -51,8 +51,7 @@ class Job(metaclass=ABCMeta):
                 failed_individual = Individual(individual.vector)
                 failed_individual.state = individual.State.FAILED
                 if individual.features["feasible"] == 0.0:
-                    individual.features["feasible"] = inf  # TODO: genetic algorithms uses this information, i dont know the
-                    # correct solution
+                    individual.features["feasible"] = inf  # TODO: genetic algorithms uses this information, i dont know the correct solution
                 self.problem.failed.append(failed_individual)
                 # in the case of failure generate new random individual
                 # TODO: create different strategies
