@@ -18,8 +18,8 @@ class JobProblem(Problem):
 
         return [result]
 
-    def evaluate_constraints(self, individual):
-        pass
+    def evaluate_inequality_constraints(self, x):
+        return []
 
 
 class TestJob(unittest.TestCase):
